@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Attribute.c,v 1.6 1999/05/28 20:43:06 danny Exp $
+ * $Id: Attribute.c,v 1.1 2004/08/28 19:25:46 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -28,10 +29,14 @@
 
 #include <LTconfig.h>
 
+#include <stdio.h>
+
+#include <Mrm/MrmPublic.h>
+
 #include "Attribute.h"
 #include "lookup.h"
+#include "main.h"
 
-extern FILE *outFile;
 
 void
 AttributeListEmit(AttributeList *this)
@@ -48,7 +53,7 @@ AttributeListEmit(AttributeList *this)
     {
 	fputc((unsigned char)MrmRtypeResource, outFile);
 
-	ArgIndex = LookUpArgIndex(ExpressionElementGetName(*j));
+	ArgIndex = __MrmLookUpArgIndex(ExpressionElementGetName(*j));
 
 	fwrite(&ArgIndex, sizeof(ArgIndex), 1, outFile);
 
@@ -97,7 +102,7 @@ AttributeListErase(AttributeList *this,
 	return Return;
     }
 
-    Exit(LOC, "Couldn't find node to Erase\n");
+    __MrmExit(LOC, "Couldn't find node to Erase\n");
 
     return NULL;
 }
