@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.0/Xm/FileSBP.h,v 1.4 2001/06/17 10:23:57 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/FileSBP.h,v 1.1 2004/08/28 19:23:25 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995-2001, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -63,7 +63,9 @@ typedef struct {
     Boolean		list_updated;
     Boolean		directory_valid;
     unsigned char	state_flags;
-
+/*
+ * The stuff below is new w.r.t. Motif 1.2
+ */
     XtEnum		path_mode;
     XtEnum		file_filter_style;
     Widget		dir_text;
@@ -99,7 +101,7 @@ typedef struct _XmFileSelectionBoxClassRec {
     XmFileSelectionBoxClassPart file_selection_box_class;
 } XmFileSelectionBoxClassRec;
 
-extern XmFileSelectionBoxClassRec xmFileSelectionBoxClassRec;
+XMLIBEXPORT extern XmFileSelectionBoxClassRec xmFileSelectionBoxClassRec;
 
 /*
  * keep those sublcasses happy
@@ -149,9 +151,6 @@ extern XmFileSelectionBoxClassRec xmFileSelectionBoxClassRec;
 #define FS_FileSearchProc(w) \
     (((XmFileSelectionBoxWidget)(w))->file_selection_box.file_search_proc)
 
-#define FS_RealDefaultButton(w) \
-    (((XmFileSelectionBoxWidget)(w))->file_selection_box.real_default_button)
-
 #define FS_FileTypeMask(w) \
     (((XmFileSelectionBoxWidget)(w))->file_selection_box.file_type_mask)
 
