@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Draw.c,v 1.9 1999/03/15 06:09:36 gritton Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Draw.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,18 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Draw.c,v 1.9 1999/03/15 06:09:36 gritton Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Draw.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $";
 
 #include <LTconfig.h>
-#include <XmI/DebugUtil.h>
+
+#include <Xm/XmP.h>
 #include <Xm/DrawP.h>
 
+#include <XmI/XmI.h>
+
+#include <XmI/DebugUtil.h>
+
+
 #define INDICATOR_GLYPH_MASK	0xf0
 
 void
@@ -41,6 +48,7 @@ XmeClearBorder(Display *display,
 }
 
 void
+
 XmeDrawShadows(Display *display,
 	       Drawable d,
 	       GC top_gc,
@@ -54,6 +62,7 @@ XmeDrawShadows(Display *display,
 		   shadow_thick, shadow_type);
 }
 
+
 void
 XmeDrawDiamond(Display *display,
 	       Drawable d,
@@ -69,6 +78,7 @@ XmeDrawDiamond(Display *display,
 		   x, y, width, height, shadow_thick, fill);
 }
 
+
 void
 XmeDrawSeparator(Display *display,
 		 Drawable d,
@@ -87,6 +97,7 @@ XmeDrawSeparator(Display *display,
 		     orientation, separator_type);
 }
 
+
 void
 XmeDrawHighlight(Display *display,
 		 Drawable d,
@@ -99,6 +110,7 @@ XmeDrawHighlight(Display *display,
 			   highlight_thick);
 }
 
+
 void
 XmeDrawArrow(Display *display,
 	     Drawable d,
@@ -114,6 +126,7 @@ XmeDrawArrow(Display *display,
 		 shadow_thick, direction);
 }
 
+
 void
 XmeDrawCircle(Display *display,
 	      Drawable d,
@@ -186,6 +199,7 @@ XmeDrawCircle(Display *display,
     }
 }
 
+
 void
 XmeDrawIndicator(Display *display, 
 		 Drawable d, 
@@ -195,52 +209,76 @@ XmeDrawIndicator(Display *display,
 		 Dimension margin, 
 		 XtEnum type)
 {
-    XPoint xp[7];
+	XPoint xp[7];
 
-    if (width <= margin << 1 || height <= margin << 1)
-	return;
-    x += margin;
-    y += margin;
-    width -= margin << 1;
-    height -= margin << 1;
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmeDrawIndicator(type %d)\n", type));
 
-    switch (type & INDICATOR_GLYPH_MASK)
-    {
-    case XmINDICATOR_CHECK_GLYPH:
-	xp[0].x = x;
-	xp[0].y = y + ((int)height * 12) / 25;
-	xp[1].x = x + ((int)width * 19) / 100;
-	xp[1].y = y + ((int)height * 29) / 100;
-	xp[2].x = x + ((int)width * 9) / 20;
-	xp[2].y = xp[5].y = y + ((int)height * 11) / 20;
-	xp[3].x = x + width;
-	xp[3].y = y - 1;
-	xp[4].x = x + width;
-	xp[4].y = y + height / 10;
-	xp[5].x = x + ((int)width * 17) / 25 + 1;
-	xp[6].x = x + ((int)width * 13) / 25;
-	xp[6].y = y + height;
-	XFillPolygon(display, d, gc, xp, 7, Nonconvex, CoordModeOrigin);
-	break;
+	if (width <= margin << 1 || height <= margin << 1)
+		return;
+	x += margin;
+	y += margin;
+	width -= margin << 1;
+	height -= margin << 1;
 
-    case XmINDICATOR_CROSS_GLYPH:
-	xp[0].x = x;
-	xp[0].y = y;
-	xp[1].x = xp[3].y = 2;
-	xp[1].y = xp[3].x = xp[4].y = 0;
-	xp[2].x = width - 2;
-	xp[2].y = height - 2;
-	xp[4].x = -1;
-	xp[5].x = 1 - width;
-	xp[5].y = 1 - height;
-	XFillPolygon(display, d, gc, xp, 6, Convex, CoordModePrevious);
-	xp[0].y = y + height;
-	xp[1].x = xp[3].y = xp[4].x = 0;
-	xp[1].y = -2;
-	xp[2].y = 2 - height;
-	xp[3].x = 2;
-	xp[4].y = 1;
-	xp[5].y = height - 1;
-	XFillPolygon(display, d, gc, xp, 6, Convex, CoordModePrevious);
-  }
+	switch (type & INDICATOR_GLYPH_MASK) {
+	case XmINDICATOR_CHECK_GLYPH:
+		xp[0].x = x;
+		xp[0].y = y + ((int)height * 12) / 25;
+		xp[1].x = x + ((int)width * 19) / 100;
+		xp[1].y = y + ((int)height * 29) / 100;
+		xp[2].x = x + ((int)width * 9) / 20;
+		xp[2].y = xp[5].y = y + ((int)height * 11) / 20;
+		xp[3].x = x + width;
+		xp[3].y = y - 1;
+		xp[4].x = x + width;
+		xp[4].y = y + height / 10;
+		xp[5].x = x + ((int)width * 17) / 25 + 1;
+		xp[6].x = x + ((int)width * 13) / 25;
+		xp[6].y = y + height;
+		XFillPolygon(display, d, gc, xp, 7, Nonconvex, CoordModeOrigin);
+		break;
+
+	case XmINDICATOR_CROSS_GLYPH:
+		xp[0].x = x;
+		xp[0].y = y;
+		xp[1].x = xp[3].y = 2;
+		xp[1].y = xp[3].x = xp[4].y = 0;
+		xp[2].x = width - 2;
+		xp[2].y = height - 2;
+		xp[4].x = -1;
+		xp[5].x = 1 - width;
+		xp[5].y = 1 - height;
+		XFillPolygon(display, d, gc, xp, 6, Convex, CoordModePrevious);
+		xp[0].y = y + height;
+		xp[1].x = xp[3].y = xp[4].x = 0;
+		xp[1].y = -2;
+		xp[2].y = 2 - height;
+		xp[3].x = 2;
+		xp[4].y = 1;
+		xp[5].y = height - 1;
+		XFillPolygon(display, d, gc, xp, 6, Convex, CoordModePrevious);
+
+	default:
+		/* The docs say don't do anything here */
+	    	break;
+	}
+}
+
+
+void 
+XmeDrawPolygonShadow(Display *display,
+                     Drawable drawable,
+                     GC top_gc,
+                     GC bottom_gc,
+                     XPoint *points,
+                     int point_count,
+                     Dimension shadow_thickness,
+                     unsigned char shadow_type)
+{
+
+  /* That function in lib/Xm/Shadow.c may be only a stub yet... */
+  _XmDrawPolygonShadow(display, drawable,
+                       top_gc, bottom_gc,
+                       points, point_count,
+                       shadow_thickness, shadow_type);
 }
