@@ -1,9 +1,9 @@
 /**
  * 
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/MenuShell.c,v 1.90 2003/07/17 22:15:45 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MenuShell.c,v 1.6 2005/03/19 10:02:25 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/MenuShell.c,v 1.90 2003/07/17 22:15:45 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MenuShell.c,v 1.6 2005/03/19 10:02:25 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -36,6 +36,8 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/MenuShell.
 #include <Xm/CascadeBGP.h>
 #include <Xm/TransltnsP.h>
 
+#include <Xm/SpecRenderT.h>
+
 #include <XmI/DebugUtil.h>
 
 /* ? */
@@ -85,17 +87,13 @@ static XtResource resources[] =
     }
 };
 
-static void MenuShellPopdownDone(Widget w, XEvent *event,
-				 String *params, Cardinal *num_params);
-static void MenuShellPopdownOne(Widget w, XEvent *event,
-				String *params, Cardinal *num_params);
-static void MenuShellPopdownEveryone(Widget w, XEvent *event,
-				     String *params, Cardinal *num_params);
-static void _XmXtMenuPopup(Widget widget, XEvent *event,
-			   String *params, Cardinal *num_params);
-static void _XmXtMenuPopdown(Widget widget, XEvent *event,
-			     String *params, Cardinal *num_params);
+static void MenuShellPopdownDone(Widget w, XEvent *event, String *params, Cardinal *num_params);
+static void MenuShellPopdownOne(Widget w, XEvent *event, String *params, Cardinal *num_params);
+static void MenuShellPopdownEveryone(Widget w, XEvent *event, String *params, Cardinal *num_params);
+static void _XmXtMenuPopup(Widget widget, XEvent *event, String *params, Cardinal *num_params);
+static void _XmXtMenuPopdown(Widget widget, XEvent *event, String *params, Cardinal *num_params);
 static void MenuShellPopupSharedMenuPane(Widget w, Widget w2, XEvent *event);
+static XmRenderTable GetRenderTable(Widget w, XtEnum renderTableType);
 
 static XtActionsRec actions[] =
 {
@@ -106,7 +104,6 @@ static XtActionsRec actions[] =
     {"ClearTraversal", _XmClearTraversal},
 };
 
-
 static XmBaseClassExtRec _XmMenuSCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -196,6 +193,10 @@ XmMenuShellClassRec xmMenuShellClassRec = {
     },
 };
 
+static XmSpecRenderTraitRec _XmMenuShellTraitRec = {
+	/* version	*/	0,
+	/* cb		*/	GetRenderTable
+};
 
 WidgetClass xmMenuShellWidgetClass = (WidgetClass)&xmMenuShellClassRec;
 
@@ -203,9 +204,14 @@ WidgetClass xmMenuShellWidgetClass = (WidgetClass)&xmMenuShellClassRec;
 static void
 class_initialize(void)
 {
-    _XmInitializeExtensions();
+	_XmInitializeExtensions();
+	_XmMenuSCoreClassExtRec.record_type = XmQmotif;
 
-    _XmMenuSCoreClassExtRec.record_type = XmQmotif;
+
+	if (! XmeTraitSet((XtPointer)xmMenuShellWidgetClass, XmQTspecifyRenderTable,
+				(XtPointer)&_XmMenuShellTraitRec)) {
+		_XmWarning(NULL, "XmMenuShell ClassInitialize: XmeTraitSet failed\n");
+	}
 }
 
 
@@ -234,47 +240,30 @@ initialize(Widget request, Widget new_w,
 
     if (MS_DefaultFontList(new_w) != NULL)
     {
-	MS_DefaultFontList(new_w) =
-	    XmFontListCopy(MS_DefaultFontList(new_w));
+	MS_DefaultFontList(new_w) = XmFontListCopy(MS_DefaultFontList(new_w));
     }
     else
     {
-	MS_DefaultFontList(new_w) = _XmGetDefaultFontList(new_w,
-							 XmBUTTON_FONTLIST);
+	MS_DefaultFontList(new_w) = _XmGetDefaultFontList(new_w, XmBUTTON_FONTLIST);
     }
     if (MS_ButtonFontList(new_w) == NULL)
     {
-	if (MS_DefaultFontList(new_w) != NULL)
-	{
-	    MS_ButtonFontList(new_w) =
-		XmFontListCopy(MS_DefaultFontList(new_w));
+	if (MS_DefaultFontList(new_w) != NULL) {
+	    MS_ButtonFontList(new_w) = XmFontListCopy(MS_DefaultFontList(new_w));
+	} else {
+	    MS_ButtonFontList(new_w) = _XmGetDefaultFontList(new_w, XmBUTTON_FONTLIST);
 	}
-	else
-	{
-	    MS_ButtonFontList(new_w) = _XmGetDefaultFontList(new_w,
-							     XmBUTTON_FONTLIST);
-	}
-    }
-    else
-    {
+    } else {
 	MS_ButtonFontList(new_w) = XmFontListCopy(MS_ButtonFontList(new_w));
     }
 
-    if (MS_LabelFontList(new_w) == NULL)
-    {
-	if (MS_DefaultFontList(new_w) != NULL)
-	{
-	    MS_LabelFontList(new_w) =
-		XmFontListCopy(MS_DefaultFontList(new_w));
+    if (MS_LabelFontList(new_w) == NULL) {
+	if (MS_DefaultFontList(new_w) != NULL) {
+	    MS_LabelFontList(new_w) = XmFontListCopy(MS_DefaultFontList(new_w));
+	} else {
+	    MS_LabelFontList(new_w) = _XmGetDefaultFontList(new_w, XmLABEL_FONTLIST);
 	}
-	else
-	{
-	    MS_LabelFontList(new_w) = _XmGetDefaultFontList(new_w,
-							    XmLABEL_FONTLIST);
-	}
-    }
-    else
-    {
+    } else {
 	MS_LabelFontList(new_w) = XmFontListCopy(MS_LabelFontList(new_w));
     }
 
@@ -753,6 +742,43 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 		       "MenuShellPopdownDone - found RC %s, posted: %s\n",
 			XtName(rc), RC_PopupPosted(rc) ? XtName(RC_PopupPosted(rc)) : "NULL"));
 
+#if 1
+    /*
+     * Don't use an event that's within the multi click time.
+     * Hopefully this is an event which we can discard :-)
+     * If we get bug reports about things not disappearing when
+     * the user is fast, this is the reason.
+     * Danny 22/04/1998
+     *
+     * I also have a bad feeling about the test above. Is it meant to do
+     * what I changed it to below ?
+     */
+    /* Danny had this ifdef'd out, but it seems to be exactly what
+     * Motif does, so I put it back in.  In Motif, a quick click/release 
+     * causes the menu to "stick" open.
+     * 	-dwilliss 28-Sep-04
+     */
+    if (_XmMenuGetInPMMode(w) && event && event->type == ButtonRelease &&
+	event->xbutton.time <= state->RC_ButtonEventStatus.time
+				+ XtGetMultiClickTime(XtDisplay(w)))
+    {
+        if (RC_Type(rc) != XmMENU_OPTION)
+        {
+	   /* Not that this _shouldn't_ be done for option menus, but I'm
+	    * not sure if this is the correct way to do it for option menus,
+	    * so in that case, leave them alone for now
+	    *  -- dwilliss 28-Sep-04
+	    */
+	    _XmMenuFocus(rc, XmMENU_FOCUS_SAVE, CurrentTime);
+	    RCClass_MenuTraverse(rc, XmTRAVERSE_HOME);
+	    XAllowEvents(XtDisplay(rc), SyncPointer, event->xbutton.time);
+        }
+      DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c user too fast\n"));
+	return;
+    }
+#endif
+
+
     _XmGetActiveTopLevelMenu(rc, &toplevelrc);
 
     if (!toplevelrc)
@@ -1158,3 +1184,22 @@ XmCreateMenuShell(Widget parent, char *name, ArgList arglist, Cardinal argcount)
     return XtCreatePopupShell(name, xmMenuShellWidgetClass, parent,
 			      arglist, argcount);
 }
+
+static XmRenderTable GetRenderTable(Widget w, XtEnum renderTableType)
+{
+	XmMenuShellWidget bb = (XmMenuShellWidget)w;
+
+	switch(renderTableType) {
+	case XmLABEL_RENDER_TABLE:
+		return bb->menu_shell.label_font_list;
+	case XmBUTTON_RENDER_TABLE:
+		return bb->menu_shell.button_font_list;
+	case XmTEXT_RENDER_TABLE:
+		return NULL;	/* ?? FIX ME FIXME */
+#if 0
+		return bb->menu_shell.text_font_list;
+#endif
+	}
+	return NULL;
+}
+
