@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/PanedW.c,v 1.21 2001/12/04 22:38:59 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/PanedW.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $
  *
  * Copyright (C) 1995-1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2001 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/PanedW.c,v 1.21 2001/12/04 22:38:59 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/PanedW.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -537,12 +537,6 @@ XmPanedWindowClassRec xmPanedWindowClassRec = {
 
 WidgetClass xmPanedWindowWidgetClass = (WidgetClass)&xmPanedWindowClassRec;
 
-/*
- * handy defines
- */
-#define _XmMin(a,b)  ((a) < (b)) ? (a) : (b)
-#define _XmMax(a,b)  ((a) < (b)) ? (b) : (a)
-
 /*
  * default number of slots.  8 seems to be a reasonable number.
  */
