@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ResConvert.c,v 1.12 2005/03/26 19:26:52 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ResConvert.c,v 1.16 2006/04/19 18:42:22 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2005 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.12 2005/03/26 19:26:52 dannybackx Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.16 2006/04/19 18:42:22 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -33,6 +33,8 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.12 2005/03/26 19:26:52 dannyb
 #include <ctype.h>
 #include <string.h>
 
+#include <X11/Xlib.h>
+#include <X11/Xfuncproto.h>
 #include <X11/Xresource.h>
 
 #include <XmI/XmI.h>
@@ -3240,13 +3242,17 @@ _XmCvtStringToRenderTable(Display *dpy,
 
 			r->pattern = FcPatternCreate();
 			if (r->font_name)
-				FcPatternAddString(r->pattern, XFT_FAMILY, r->font_name);
+				FcPatternAddString(r->pattern, XFT_FAMILY, 
+				  (unsigned char*)r->font_name);
 			if (r->font_foundry)
-				FcPatternAddString(r->pattern, XFT_FOUNDRY, r->font_foundry);
+				FcPatternAddString(r->pattern, XFT_FOUNDRY, 
+				  (unsigned char*)r->font_foundry);
 			if (r->font_encoding)
-				FcPatternAddString(r->pattern, XFT_ENCODING, r->font_encoding);
+				FcPatternAddString(r->pattern, XFT_ENCODING, 
+				  (unsigned char*)r->font_encoding);
 			if (r->font_style)
-				FcPatternAddString(r->pattern, XFT_STYLE, r->font_style);
+				FcPatternAddString(r->pattern, XFT_STYLE, 
+				  (unsigned char*)r->font_style);
 			if (r->font_size)
 				FcPatternAddInteger(r->pattern, XFT_SIZE, r->font_size);
 			if (r->pixel_size)
@@ -3275,6 +3281,10 @@ _XmCvtStringToRenderTable(Display *dpy,
 	}
 #endif
 
+	/* Make sure we have a display */
+	if (! rt->dpy)
+		rt->dpy = dpy;
+
 	/*
 	 * Do the dance, as in any Xt converter, to return your info.
 	 */
