@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Traversal.c,v 1.2 2004/09/28 18:37:21 dannybackx Exp $
+ * $Id: Traversal.c,v 1.4 2009/04/29 09:45:14 paulgevers Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995-2001, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Traversal.c,v 1.2 2004/09/28 18:37:21 dannybackx Exp $";
+static const char rcsid[] = "$Id: Traversal.c,v 1.4 2009/04/29 09:45:14 paulgevers Exp $";
 
 #include <LTconfig.h>
 
@@ -1807,12 +1807,6 @@ _XmGetFocusData(Widget wid)
 
 	return fd;
     }
-    else if (XtIsSubclass(wid, xmMenuShellWidgetClass) && MS_FocusData(wid) != 0)
-    {
-       XmMenuShellWidget msh = (XmMenuShellWidget)wid;
-       MS_FocusData(wid)->focus_policy = msh->menu_shell.focus_policy;
-       return (MS_FocusData(wid));
-    }
 
     DEBUGOUT(_LtDebug(__FILE__, orig,
 		      "_XmGetFocusData: not LessTif vendorshell subclass\n"));
@@ -3746,29 +3740,24 @@ XmGetTabGroup(Widget widget)
 
 
 extern Boolean
-XmProcessTraversal(Widget widget,
-		   XmTraversalDirection direction)
+XmProcessTraversal(Widget widget, XmTraversalDirection direction)
 {
-    Widget shell = _XmFindTopMostShell(widget);
-    Widget ve;
+	Widget shell = _XmFindTopMostShell(widget);
+	Widget ve;
 
-    DEBUGOUT(_LtDebug(__FILE__, widget, "XmProcessTraversal\n"));
+	DEBUGOUT(_LtDebug(__FILE__, widget, "XmProcessTraversal\n"));
 
-    ve = _LtFindVendorExt(shell);
+	ve = _LtFindVendorExt(shell);
 
-    if (!ve)
-    {
-	return False;
-    }
+	if (!ve) {
+		return False;
+	}
 
-    if (VSEP_FocusPolicy(ve) != XmEXPLICIT)
-    {
-	return False;
-    }
+	if (VSEP_FocusPolicy(ve) != XmEXPLICIT) {
+		return False;
+	}
 
-    _XmProcessTraversal(widget, direction, True);
-
-    return True;
+	return _XmMgrTraversal(widget, direction);
 }
 
 
