@@ -1,12 +1,15 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm-2.1/translations/test1.c,v 1.2 2005/08/06 10:52:04 amai Exp $ */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
+
 #include <Xm/XmP.h>
 #include <Xm/TransltnsP.h>
 
 struct {
-        char    *n;
-        char    *t;
+        const char    *n;
+        const char    *t;
 } list[] = {
 	{ "_XmArrowB_defaultTranslations", _XmArrowB_defaultTranslations },
 	{ "_XmBulletinB_defaultTranslations", _XmBulletinB_defaultTranslations },
@@ -88,14 +91,15 @@ char *copyright =
 " *\n"
 " **/\n";
 
+int
 main()
 {
 	int	i;
-	char	*p;
+	const 	char *p;
 
         printf(copyright);
         printf("\n");
-        printf("static char rcsid[] = \"$Id: test1.c,v 1.1 1997/07/03 00:54:07 miers Exp $\";\n");
+        printf("static char rcsid[] = \"$Id: test1.c,v 1.2 2005/08/06 10:52:04 amai Exp $\";\n");
         printf("\n");
 	printf("#include <Xm/XmP.h>\n");
 	printf("#include <Xm/TransltnsP.h>\n");
@@ -125,5 +129,5 @@ main()
 		putchar('\n');
 		putchar('\n');
 	}
+	exit(0);
 }
-
