@@ -11,10 +11,21 @@ void Print(Widget w, XtPointer client, XtPointer call)
 {
 	XmCommandCallbackStruct *p = (XmCommandCallbackStruct *)call;
 	char			*t;
+	XmString		comtxt;
 
 	XmStringGetLtoR(p->value, XmFONTLIST_DEFAULT_TAG, &t);
 	fprintf(stderr, "Command : '%s'\n", t);
 	XtFree(t);
+
+	XtVaGetValues(w, XmNcommand, &comtxt, NULL );
+	if (!XmStringEmpty(comtxt)) {
+		fprintf(stderr, "Yow then\n");
+	} else {
+		fprintf(stderr, "Yow else\n");
+	}
+	XmStringGetLtoR(comtxt, XmFONTLIST_DEFAULT_TAG, &t);
+	fprintf(stderr, "Yow(%s)\n", t);
+	XtFree(t);
 }
 
 int
