@@ -1,3 +1,5 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/drag_help/import_bitmap.c,v 1.3 2001/05/23 13:42:30 amai Exp $ */
+
 #include <Xm/Xm.h>
 #include <Xm/DragDrop.h>
 #include <Xm/MessageB.h>
@@ -76,7 +78,7 @@ import_bitmap(w, client_data, call_data)
 
 		XtVaGetValues(drop_data->dragContext, XmNexportTargets,
 			   &export_list, XmNnumExportTargets, &export_count,
-			      0);
+			      NULL);
 		for (i = 0; i < export_count; i++)
 			if (export_list[i] == XA_STRING)
 				got_string = True;
