@@ -1,4 +1,4 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/labelg/test4.c,v 1.5 2002/04/15 18:17:21 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,8 +6,10 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/BulletinB.h>
 #include <Xm/LabelG.h>
@@ -32,14 +34,14 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmLabelGadgetClass, bb, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		 */
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char *)before);
 	    }
 	    diff = iter;
 	}
