@@ -40,13 +40,23 @@ char *argv[];
     label = XmStringCreateLocalized("Hello World!");
 
     hello = XtVaCreateManagedWidget(
-	   "hello",            /* arbitrary widget name */
+	   "hellohellohello",            /* arbitrary widget name */
 	   xmLabelWidgetClass,    /* widget class from Label.h */
 	   mw,            /* parent widget */
 	   NULL);              /* terminate varargs list */
 
     /*   XmMainWindowSetAreas(mw,NULL,NULL,NULL,NULL,hello); */
     XtRealizeWidget (toplevel);
-    XtAppMainLoop (app);
+
+
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,  508,  524,   94,   17, 0,0,0, /* mainw */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,   94,   17, 0,0,0, /* hello */ 
+    };
+    PrintDetails(toplevel,Expected);
+};
+  LessTifTestMainLoop(toplevel);
+
     exit(0);
 }
