@@ -1,6 +1,9 @@
-/* test of selection boxes */
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/messagebox/test7.c,v 1.5 2001/05/15 14:08:34 amai Exp $ 
+  test of selection boxes */
 
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/Xm.h>
 #include <Xm/RowColumn.h>
 #include <Xm/PushB.h>
@@ -13,6 +16,9 @@
 #include <Xm/XmP.h>
 #include <Xm/MessageB.h>
 
+#include "../../common/Test.h"
+
+
 Widget toplevel, box, push;
 
 void Quit(Widget w, XtPointer client, XtPointer call)
