@@ -1,4 +1,8 @@
-/* test for M*tif to see what the compiled Resources look like */
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/misc/test6.c,v 1.4 2002/04/17 16:22:01 amai Exp $
+   test for M*tif to see what the compiled Resources look like */
+
+#include <stdlib.h>
+#include <stdio.h>
 
 #include <Xm/Xm.h>
 #include <Xm/ExtObjectP.h>
