@@ -1,4 +1,8 @@
-/* Actions */
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/misc/test9.c,v 1.3 2002/04/17 16:22:01 amai Exp $
+   Actions */
+
+#include <stdlib.h>
+
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <Xm/Label.h>
