@@ -46,7 +46,20 @@ main(int argc, char **argv)
    XtManageChild(rowcol);
    
    XtRealizeWidget(toplevel);
+  {
+  static XtWidgetGeometry Expected[] = {
+  	CWWidth | CWHeight,		0,	0,	121,	87,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	3,	115,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	31,	115,	25,	0,0,0,
+  	CWWidth | CWHeight | CWX | CWY,	3,	59,	115,	25,	0,0,0,
+};
+
+  PrintDetails(toplevel, Expected);
+  }
+    LessTifTestMainLoop(toplevel);
+    /*
    XtAppMainLoop(app);
+   */
    
    exit(0);
 }
