@@ -1,3 +1,4 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/rowcolumn/test3.c,v 1.6 2002/05/01 15:39:21 amai Exp $ */
 /** test3 -- horizontal tight layout of widgets with XmNadjustLast = False.
 
     resulting layout should be:
@@ -11,12 +12,14 @@
 
 **/
 
+#include <stdlib.h>
+
 #include <Xm/XmP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/PushB.h>
 
 #include "../../common/Test.h"
-#include "../../common/DumpLayout.h"
+
 
 int
 main(int argc, char **argv)
