@@ -1,4 +1,4 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/scrolledwindow/test11.c,v 1.8 2001/05/23 14:30:30 amai Exp $
  * create a scrolled window with a drawing area inside... resize the
  * drawing area when the pushbutton is clicked (also draw a line
  * to show the clipping area)
@@ -6,12 +6,15 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <Xm/Form.h>
 #include <Xm/Label.h>
 #include <Xm/PushB.h>
 #include <Xm/ScrolledW.h>
 #include <Xm/DrawingA.h>
 
+#include "../../common/Test.h"
+
 Widget toplevel;
 Widget form;
 Widget scrollw;
