@@ -1,3 +1,6 @@
+/* $Id: test9.c,v 1.4 2000/12/08 14:31:26 amai Exp $ */
+
+#include <stdlib.h>
 #include <Xm/Text.h> 
 
 #define	LS	"Axelle Red / A Tatons this is a very long title for a CD"
@@ -27,7 +30,16 @@ main(int argc, char **argv)
   XmTextSetCursorPosition(one, 56);
 
   XtRealizeWidget(toplevel);
-  XtAppMainLoop(app);
+
+  
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   57,   73,  360,   31, 0,0,0, /* one */ 
+    };
+    PrintDetails(toplevel,Expected);
+};
+  LessTifTestMainLoop(toplevel);
+
   exit(0);
 }
 
