@@ -17,7 +17,15 @@ main(int argc, char **argv)
                                 NULL); 
 
   XtRealizeWidget(toplevel);
-  XtAppMainLoop(app);
+
+  
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   50,   50,   78,   31, 0,0,0, /* one */ 
+    };
+    PrintDetails(toplevel,Expected);
+};
+  LessTifTestMainLoop(toplevel);
 
   exit(0);
 }
